@@ -1,7 +1,7 @@
 import zipfile
 
-from src.sqlcarve.validator.executeQuery import Connection, Execution
-from src.sqlcarve.validator.validator import valid_parser, getZipStatement, choose_dir_for_validation
+from src.sqlcarve.validator.executeQuery import *
+#from src.sqlcarve.validator.validator import *
 
 def analyse(referencefile, fichier):
     archive = zipfile.ZipFile(fichier, 'r')
@@ -23,3 +23,5 @@ def analyse(referencefile, fichier):
     else:
         print(list_req[1])
 
+if __name__ == "__main__":
+    analyse(r"C:\Users\cjsou\PycharmProjects\ProjetPresse\src\resources\reference.json", r"C:\Users\cjsou\PycharmProjects\ProjetPresse\src\resources\prese-structure-devoir.zip")
\ No newline at end of file
